| post_comments | R Documentation |
First, extracts comments from issues file for interviews to reject. Then, posts those comments, if any
post_comments(
df_to_reject,
df_issues,
server = Sys.getenv("SUSO_SERVER"),
workspace = Sys.getenv("SUSO_WORKSPACE"),
user = Sys.getenv("SUSO_USER"),
password = Sys.getenv("SUSO_PASSWORD")
)
df_to_reject |
Data frame containing interviews to reject. |
df_issues |
Data frame of issues. |
server |
Full server web address (e.g., |
workspace |
Character. Name of the workspace whose questionnaires and associated interviews to get. |
user |
API user name |
password |
API password |
Server-side effect of posting all applicable comments to all applicable questionnaires
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.