| reject_interview | R Documentation |
Reject interview using the appropriate set of rejection API calls
reject_interview(
interview__id,
interview__status,
reject_comment,
statuses_to_reject = c(100, 120),
reject_hq_approved = TRUE,
server = Sys.getenv("SUSO_SERVER"),
workspace = Sys.getenv("SUSO_WORKSPACE"),
user = Sys.getenv("SUSO_USER"),
password = Sys.getenv("SUSO_PASSWORD")
)
interview__id |
Character. GUID for interview found in |
interview__status |
Numeric. Supports values in set c(100, 120, 130). |
reject_comment |
Character. Comment to post upon rejection |
statuses_to_reject |
Numeric vector. Supports values in set c(100, 120, 130). |
reject_hq_approved |
Boolean. Flag that determines whether HeadquartersApproved assignments will be rejected or not. Default behavior is to reject. |
server |
Full server web address (e.g., |
workspace |
Character. Name of the workspace whose questionnaires and associated interviews to get. |
user |
API user name |
password |
API password |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.